"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SaveTranslatedCollectionUseCase = void 0;
var _Identifier = require("../../Identifier");
var _GetOrCreateTranslatedCollectionUseCase = require("./GetOrCreateTranslatedCollectionUseCase");
var _UpdateTranslatedCollectionRepository = require("../repository/UpdateTranslatedCollectionRepository");
var _CreateTranslatedCollectionRepository = require("../repository/CreateTranslatedCollectionRepository");
var _TranslatedItem = require("../domain/TranslatedItem");
class SaveTranslatedCollectionUseCase {
  constructor(context) {
    this.context = context;
  }
  async execute(params) {
    const getOrCreate = new _GetOrCreateTranslatedCollectionUseCase.GetOrCreateTranslatedCollectionUseCase(this.context);
    const collection = await getOrCreate.execute({
      collectionId: params.collectionId,
      languageCode: params.languageCode
    });
    const identity = this.getIdentity();
    const newItems = params.items.map(item => {
      // If a value was unset, we want to unset the translatedOn and translatedBy.
      const value = item.value ? item.value : undefined;
      const translatedOn = item.translatedOn ? new Date(item.translatedOn) : undefined;
      return _TranslatedItem.TranslatedItem.create({
        itemId: item.itemId,
        value,
        translatedOn: translatedOn ?? value ? new Date() : undefined,
        translatedBy: value ? identity : undefined
      });
    });
    collection.updateItems(newItems);
    if (collection.getId()) {
      const update = new _UpdateTranslatedCollectionRepository.UpdateTranslatedCollectionRepository(this.context);
      await update.execute(collection);
    } else {
      collection.setId(_Identifier.Identifier.generate());
      const create = new _CreateTranslatedCollectionRepository.CreateTranslatedCollectionRepository(this.context);
      await create.execute(collection);
    }
    return collection;
  }
  getIdentity() {
    const identity = this.context.security.getIdentity();
    return {
      id: identity.id,
      type: identity.type,
      displayName: identity.displayName || ""
    };
  }
}
exports.SaveTranslatedCollectionUseCase = SaveTranslatedCollectionUseCase;

//# sourceMappingURL=SaveTranslatedCollectionUseCase.js.map